import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom
} from 'd3';


const svg = select('svg');
const margin = { top: 20, right: 30, bottom: 120, left: 0};

// const width = +svg.attr('width');
const width = +svg.attr('width') / 3;
const height = +svg.attr('height');


const margin_1 = { top: 20, right: 30, bottom: 120, left: 40 };
var render1_svg = svg.append('g')
    .attr('transform', `translate(${margin_1.left},${margin_1.top})`);
var render1_x=render1_svg.append('g');
var render1_y=render1_svg.append('g');

//==========SUSPICIOUSNESS===================
//===========================================
const render1 = data => {
  const xValue = d => d.suspiciousness;
  const yValue = d => d.id;
  
  const innerWidth = width - margin_1.left - margin_1.right;
  const innerHeight = height - margin_1.top - margin_1.bottom;
  
  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);
  
  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.1);
  
  
  render1_y.call(axisLeft(yScale))
  	.select('.domain')
  	//.selectAll('.domain, .tick line')
  	.remove();
  
  
  render1_x.call(axisBottom(xScale))
    .attr('transform', `translate(0,${innerHeight})`);
  
  var prev = render1_svg.selectAll('rect');
  render1_svg.selectAll('rect').data(data)
    .enter().append('rect')
  	.merge(prev)
      .attr('y', d => yScale(yValue(d)))
      .attr('width', d => xScale(xValue(d)))
      .attr('height', yScale.bandwidth())
  		.attr('fill', "red");
  
  render1_svg.append('text')
  	.attr('y', -5)
  	.text('Suspicousness (Top 25 Lines)');
  
   
  d3.select("#sort-susp-button")
  	.on("click", function() {
        data.sort(function(a,b) {
          return xScale(b.suspiciousness) - xScale(a.suspiciousness);
        });

        render1(data);
        render2(data);
        render3(data);
    });
  
  
};


var render2_svg = svg.append('g')
    .attr('transform', `translate(${margin.left + width},${margin.top})`);
var render2_x=render2_svg.append('g');
var render2_y=render2_svg.append('g');

//==========RECENCY==========================
//===========================================
const render2 = data => {
  const xValue = d => d.recency;
  const yValue = d => d.id;

  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);
  
  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.1);
  
  render2_y.call(axisLeft(yScale))
  		.select('.domain')
  		//.selectAll('.domain, .tick line')
  		.remove();
  
  render2_x.call(axisBottom(xScale))
    .attr('transform', `translate(0,${innerHeight})`);
  
  var prev=render2_svg.selectAll('rect');
  render2_svg.selectAll('rect').data(data)
    .enter().append('rect')
  	.merge(prev)
      .attr('y', d => yScale(yValue(d)))
      .attr('width', d => xScale(xValue(d)))
      .attr('height', yScale.bandwidth())
  		.attr('fill', "orange");
  
  
  render2_svg.append('text')
  	.attr('y', -5)
  	.text('Recency');
  
  d3.select("#sort-recency-button")
  	.on("click", function() {
        data.sort(function(a,b) {
          return xScale(b.recency) - xScale(a.recency);
        });

        render1(data);
        render2(data);
        render3(data);
    });
  
};


var render3_svg_g1 = svg.append('g')
	.attr('transform', `translate(${margin.left + (2 * width)},${margin.top})`);
var render3_svg_x = render3_svg_g1.append('g');
var render3_svg_y = render3_svg_g1.append('g');

//==========LINE COMPLEXITY==================
//===========================================
const render3 = data => {
  const xValue = d => d.line_complexity;
  const yValue = d => d.id;

 
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth])
  	.clamp(true);
  
  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.1);
  
  const g = render3_svg_g1;
  
  render3_svg_y.call(axisLeft(yScale))
  	.select('.domain')
  	//.selectAll('.domain, .tick line')
  		.remove();
  
  render3_svg_x.call(axisBottom(xScale))
    .attr('transform', `translate(0,${innerHeight})`);
  
  var prev = g.selectAll('rect');
  g.selectAll('rect').data(data)
    .enter().append('rect')
  	.merge(prev)
      .attr('y', d => yScale(yValue(d)))
      .attr('width', d => xScale(xValue(d)))
      .attr('height', yScale.bandwidth())
  		.attr('fill', "steelblue");

   g.append('text')
  	.attr('y', -5)
  	.text('Line Complexity');
  
  
	d3.select("#sort-complexity-button")
  	.on("click", function() {
    	data.sort(function(a,b) {
        return xScale(b.line_complexity) - xScale(a.line_complexity);
      });

      render1(data);
      render2(data);
      render3(data);
  	});
  
};


csv('data.csv').then(data => {
  data.forEach(d => {
    d.suspiciousness = +d.suspiciousness;
    d.recency = +d.recency;
    d.line_complexity = +d.line_complexity;
  });
  render1(data);
  render2(data);
  render3(data);
});

